@@ -3,6 +3,12 @@ from typing import Dict, List, Callable
 from aiosow.perpetuate import perpetuate
 
 SETUP_FUNCTIONS: List = []
+TRIGGER_ROUTINES = False
+
+
+def trigger_routines():
+    global TRIGGER_ROUTINES
+    TRIGGER_ROUTINES = True
 
 
 def clear_setups():  # pragma: no cover
@@ -10,6 +16,11 @@ def clear_setups():  # pragma: no cover
     SETUP_FUNCTIONS = []
 
 
+def get_setups():  # pragma: no cover
+    global SETUP_FUNCTIONS
+    return SETUP_FUNCTIONS
+
+
 def setup(func: Callable) -> Callable:
     """
     Decorator to add a function to the list of initialization functions.
@@ -20,8 +31,11 @@ def setup(func: Callable) -> Callable:
     **Returns**:
     - func (Callable): The same function, unchanged.
     """
-    logging.info("+ setup %s", func.__name__)
-    SETUP_FUNCTIONS.append(func)
+    if func in SETUP_FUNCTIONS:
+        logging.debug("duplicate setup declaration of %s is ignored", func.__name__)
+    else:
+        logging.info("+ setup %s", func.__name__)
+        SETUP_FUNCTIONS.append(func)
     return func
 
 
